#!/bin/sh

uts_release ()
{
   if [ -f $1/include/linux/version.h ]; then
      sed -ne '/#define UTS_RELEASE "\(.*\)"/{
         s//\1/p
         q
      }' $1/include/linux/version.h
   else
      echo "ERROR:  no valid headers found"
      exit 1
   fi
}

deb_release ()
{
   UTS_RELEASE=`uts_release $1`

   if [ -f $1/debian/changelog ]; then
      sed -ne '1{
         s/^[^(]*(//
         s/)[^)]*$//p
         q
      }' $1/debian/changelog
   elif [ -f /usr/doc/kernel-headers-$UTS_RELEASE/changelog.Debian.gz ]; then
      gunzip < /usr/doc/kernel-headers-$UTS_RELEASE/changelog.Debian.gz | \
      sed -ne '1{
         s/^[^(]*(//
         s/)[^)]*$//p
         q
      }'
   else
      echo $UTS_RELEASE
   fi
}

deb_control ()
{
   echo 'Source: linux-wlan-ng'
   echo 'Section: base'
   echo 'Priority: extra'
   echo 'Maintainer: David Everly <deckrider@yahoo.com>'
   echo 'Standards-Version: 3.0.1'
   echo ''
   echo 'Package: linux-wlan-ng-common'
   echo 'Architecture: any'
   echo 'Depends: ${shlibs:Depends}'

   RECOMMENDS='Recommends: '

   for i in $* ; do
      UTS_RELEASE=`uts_release $i`
      if [ "$RECOMMENDS" = "Recommends: " ] ; then
         RECOMMENDS="${RECOMMENDS}linux-wlan-ng-modules-$UTS_RELEASE"
      else
         RECOMMENDS="${RECOMMENDS}|linux-wlan-ng-modules-$UTS_RELEASE"
      fi
   done

   echo "$RECOMMENDS"

   echo 'Description: linux-wlan-ng common utilities'
   echo ' This package contains the set of common utilities needed to use'
   echo ' linux-wlan-ng.  This package is useless without the appropriate'
   echo ' linux-wlan-ng-modules for the kernel you are running.'
   echo ''

   for i in $* ; do
      UTS_RELEASE=`uts_release $i`
      DEB_RELEASE=`deb_release $i`

      echo "Package: linux-wlan-ng-modules-$UTS_RELEASE"
      echo 'Architecture: any'

      DEPENDS="Depends: modutils, kernel-image-$UTS_RELEASE (= $DEB_RELEASE), "
      DEPENDS=${DEPENDS}'linux-wlan-ng-common (= ${Source-Version})'
      echo "$DEPENDS"

      CONFLICTS="Conflicts: kernel-image-$UTS_RELEASE (<< $DEB_RELEASE),"
      CONFLICTS="$CONFLICTS kernel-image-$UTS_RELEASE (>> $DEB_RELEASE)"
      echo "$CONFLICTS"

      echo "Description: linux-wlan-ng Modules for Linux (kernel $UTS_RELEASE)."
      echo ' This package contains the set of loadable kernel modules for the'
      echo ' linux-wlan-ng applications program interface.  They have been'
      echo ' compiled to be compatible with the kernel in the '
      echo " kernel-image-$UTS_RELEASE package version $DEB_RELEASE."
      echo ' .'
      echo ' The utilities in the linux-wlan-ng-common package are required'
      echo ' to use these modules.'

      echo ''
   done
}

# main

if [ "x$1" = "x-u" ] ; then
   uts_release $2
elif [ "x$1" = "x-c" ] ; then
   shift
   deb_control $*
else
   echo "USAGE:  $0 {-c kernel-source-dir|-u kernel-source-dirs}"
   exit 1
fi

